==> ads-lib-3.5.0-sources.jar: com/google/api/ads/adwords/lib/utils/examples/ArgumentNames.java <==
// Copyright 2017 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.api.ads.adwords.lib.utils.examples;

/**
 * Contains command line argument formats for example code.
 */
public final class ArgumentNames {

  public static final String AD_GROUP_ID = "--adGroupId";

  public static final String AD_ID = "--adId";

  public static final String BASE_CAMPAIGN_ID = "--baseCampaignId";

  public static final String BUDGET_ID = "--budgetId";

  public static final String BUSINESS_ACCOUNT_IDENTIFIER = "--businessAccountIdentifier";

  public static final String CAMPAIGN_ID = "--campaignId";

  public static final String CONVERSION_NAME = "--conversionName";

  public static final String CONVERSION_TIME = "--conversionTime";

  public static final String CONVERSION_VALUE = "--conversionValue";

  public static final String CREATE_DEFAULT_PARTITION = "--createDefaultPartition";

  public static final String CRITERION_ID = "--criterionId";

  public static final String DRAFT_ID = "--draftId";

  public static final String FEED_NAME = "--feedName";

  public static final String GCL_ID = "--gclId";

  public static final String GMB_ACCESS_TOKEN = "--gmbAccessToken";

  public static final String GMB_EMAIL_ADDRESS = "--gmbEmailAddress";

  public static final String KEYWORD_ID = "--keywordId";

  public static final String LABEL_ID = "--labelId";

  public static final String LOCATION_FEED_ID = "--locationFeedId";

  public static final String MERCHANT_ID = "--merchantId";

  public static final String SERVICE_LINK_ID = "--serviceLinkId";

  public static final String TRIAL_ID = "--trialId";

}

==> ads-lib-3.14.2-sources.jar: com/google/api/ads/adwords/lib/utils/examples/ArgumentNames.java <==
// Copyright 2017 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.api.ads.adwords.lib.utils.examples;

/**
 * Contains command line argument formats for example code.
 */
public final class ArgumentNames {

  public static final String AD_GROUP_ID = "--adGroupId";

  public static final String AD_ID = "--adId";

  public static final String BASE_CAMPAIGN_ID = "--baseCampaignId";

  public static final String BRIDGE_MAP_VERSION_ID = "--bridgeMapVersionId";

  public static final String BUDGET_ID = "--budgetId";

  public static final String BUSINESS_ACCOUNT_IDENTIFIER = "--businessAccountIdentifier";

  public static final String CAMPAIGN_ID = "--campaignId";

  public static final String CAMPAIGN_ID_1 = "--campaignId1";

  public static final String CAMPAIGN_ID_2 = "--campaignId2";

  public static final String CONVERSION_NAME = "--conversionName";

  public static final String CONVERSION_TIME = "--conversionTime";

  public static final String CONVERSION_VALUE = "--conversionValue";

  public static final String CPC_BID_MICRO_AMOUNT = "--cpcBidMicroAmount";

  public static final String CREATE_DEFAULT_PARTITION = "--createDefaultPartition";

  public static final String CRITERION_ID = "--criterionId";

  public static final String DRAFT_ID = "--draftId";

  public static final String EMAIL_ADDRESS = "--emailAddress";

  public static final String EXTERNAL_UPLOAD_ID = "--externalUploadId";

  public static final String FEED_NAME = "--feedName";

  public static final String GCL_ID = "--gclId";

  public static final String GMB_ACCESS_TOKEN = "--gmbAccessToken";

  public static final String GMB_EMAIL_ADDRESS = "--gmbEmailAddress";

  public static final String KEYWORD_ID = "--keywordId";

  public static final String LABEL_ID = "--labelId";

  public static final String LOCATION_FEED_ID = "--locationFeedId";

  public static final String MERCHANT_ID = "--merchantId";

  public static final String PARTNER_ID = "--partnerId";

  public static final String SERVICE_LINK_ID = "--serviceLinkId";

  public static final String TRIAL_ID = "--trialId";

  public static final String UPLOAD_TIME = "--uploadTime";

  public static final String USER_LIST_ID = "--userListId";

  public static final String OFFLINE_DATA_UPLOAD_TYPE = "--offlineDataUploadType";

}
